# olcarpc

This is a Python 3.7+ gRPC client library for 
[openLCA 2](https://www.openlca.org/). It can be installed via pip:

```bash
pip install olcarpc
```

See the [openLCA API documentation](https://github.com/GreenDelta/openLCA-ApiDoc)
for the supported service and message types. Also, the [examples](./examples)
folder contains some examples.
